@@ -1,4 +1,8 @@
-require 'puppetlabs_spec_helper/module_spec_helper'
+if ENV.fetch('IMPLEMENTATION', 'puppet') == 'puppet'
+  require 'puppetlabs_spec_helper/module_spec_helper'
+else
+  require 'voxpupuli/test/spec_helper'
+end
 require 'shared_examples'
 require 'puppet-openstack_spec_helper/facts'
 
@@ -9,7 +13,6 @@ RSpec.configure do |c|
   c.alias_it_should_behave_like_to :it_raises, 'raises'
 
   c.module_path = File.join(fixture_path, 'modules')
-  c.manifest_dir = File.join(fixture_path, 'manifests')
 end
 
 at_exit { RSpec::Puppet::Coverage.report! }
